==> vmd-0.95.tar.gz: vmd-0.95/src/MoleculeFileRaster3D.h <==
/***************************************************************************
 * RCS INFORMATION:
 *
 *	$RCSfile: MoleculeFileRaster3D.h,v $
 *	$Author: dalke $	$Locker:  $		$State: Exp $
 *	$Revision: 1.1 $	$Date: 1995/02/12 07:24:14 $
 *
 ***************************************************************************
 * DESCRIPTION:
 *   read in from a Raster3D data file
 *
 ***************************************************************************
 * REVISION HISTORY:
 *
 * $Log: MoleculeFileRaster3D.h,v $
 * Revision 1.1  1995/02/12  07:24:14  dalke
 * Initial revision
 *
 ***************************************************************************/

// All this does is read the data into the rendering command list
// there is no way to change anything -- maybe in the future?

#ifndef MOLECULEFILERaster3D_H
#define MOLECULEFILERaster3D_H
#include "MoleculeFile.h"

class MoleculeFileRaster3D : public MoleculeFile
{
 private:
   // I don't have to save anything since I cannot
   // yet manipulate the objects
   
   float minx, miny, minz, maxx, maxy, maxz;
 public:
   MoleculeFileRaster3D(char *filename, Scene *);
   MoleculeFileRaster3D(char *filename, Displayable *);
   virtual ~MoleculeFileRaster3D(void);

   // create the molecule and calls the parents
   virtual int create(void);
   virtual void create_cmdlist(void) { }; // list is actually made in create

   // center of volume
   virtual void cov(float &x, float &y, float&z) {
      x = (minx + maxx)/2;
      y = (miny + maxy)/2;
      z = (minz + maxz)/2;
   }
   // get the size
   virtual float scale_factor(void) {
      float wx = maxx - minx;
      float wy = maxy - miny;
      float wz = maxz - minz;
      if (wx > wy) {
	 if (wx > wz) {
	    return 2.0/wx;  // the 2.0 is to fit the system in
	 } else {           // a box from -1 to 1
	    return 2.0/wz;
	 }
      } else {
	 if (wy > wz) {
	    return 2.0/wy;
	 } else {
	    return 2.0/wz;
	 }
      }
   }
};

#endif

==> vmd-0.96.tar.gz: vmd-0.96/src/MoleculeFileRaster3D.h <==
/***************************************************************************
 *cr                                                                       
 *cr            (C) Copyright 1995 The Board of Trustees of the           
 *cr                        University of Illinois                       
 *cr                         All Rights Reserved                        
 *cr                                                                   
 ***************************************************************************/

/***************************************************************************
 * RCS INFORMATION:
 *
 *	$RCSfile: MoleculeFileRaster3D.h,v $
 *	$Author: billh $	$Locker:  $		$State: Exp $
 *	$Revision: 1.2 $	$Date: 95/03/24 18:50:50 $
 *
 ***************************************************************************
 * DESCRIPTION:
 *   read in from a Raster3D data file
 *
 ***************************************************************************
 * REVISION HISTORY:
 *
 * $Log:	MoleculeFileRaster3D.h,v $
 * Revision 1.2  95/03/24  18:50:50  billh
 * Added copyright notice to top of file; made sure all virtual routines
 * are defined in the .C file, not in the .h file.
 * 
 * Revision 1.1  1995/02/12  07:24:14  dalke
 * Initial revision
 *
 ***************************************************************************/
#ifndef MOLECULEFILERaster3D_H
#define MOLECULEFILERaster3D_H

// All this does is read the data into the rendering command list
// there is no way to change anything -- maybe in the future?

#include "MoleculeFile.h"

class MoleculeFileRaster3D : public MoleculeFile
{
 private:
   // I don't have to save anything since I cannot
   // yet manipulate the objects
   
   float minx, miny, minz, maxx, maxy, maxz;
 public:
   MoleculeFileRaster3D(char *filename, Scene *);
   MoleculeFileRaster3D(char *filename, Displayable *);
   virtual ~MoleculeFileRaster3D(void);

   // create the molecule and calls the parents
   virtual int create(void);

   // center of volume, and scaling factor
   virtual void cov(float &x, float &y, float&z);
   virtual float scale_factor(void);
};

#endif
